**Example 1: 删除日志导出**



Input: 

```
tccli cls DeleteExport --cli-unfold-argument  \
    --ExportId 57196a6a-7622-47be-bc92-d2ebea959a0f
```

Output: 
```
{
    "Response": {
        "RequestId": "6ef60bec-0242-43af-bb20-270359fb54a7"
    }
}
```

